@@ -251,7 +251,7 @@ class EfdClient:
             ret = pd.DataFrame()
         return ret
 
-    async def select_top_n(self, topic_name, fields, num, index=None):
+    async def select_top_n(self, topic_name, fields, num, time_cut=None, index=None):
         """Select the most recent N samples from a set of topics in a single subsystem.
         This method does not guarantee sort direction of the returned rows.
 
@@ -263,6 +263,9 @@ class EfdClient:
             Name of field(s) to query.
         num : `int`
             Number of rows to return.
+        time_cut : `astropy.time.Time`, optional
+            Use a time cut instead of the most recent entry.
+            (default is `None`)
         index : `int`, optional
             For indexed topics set this to the index of the topic to query
             (default is `None`)
@@ -276,11 +279,18 @@ class EfdClient:
         # The "GROUP BY" is necessary to return the tags
         limit = f"GROUP BY * ORDER BY DESC LIMIT {num}"
 
-        # Deal with index
-        istr = ''
+        # Deal with time cut and index
+        pstr = ''
+        if time_cut:
+            pstr = f" WHERE time < '{time_cut}Z'"
         if index:
             parts = topic_name.split('.')
-            istr = f' WHERE {parts[-2]}ID = {index}'  # The CSC name is always the penultimate
+            # The CSC name is always the penultimate
+            istr = f'{parts[-2]}ID = {index}'
+            if pstr != '':
+                pstr += f' AND {istr}'
+            else:
+                pstr = f' WHERE {istr}'
 
         if isinstance(fields, str):
             fields = [fields, ]
@@ -289,7 +299,7 @@ class EfdClient:
             fields = [fields, ]
 
         # Build query here
-        query = f'SELECT {", ".join(fields)} FROM "{self.db_name}"."autogen"."{topic_name}"{istr} {limit}'
+        query = f'SELECT {", ".join(fields)} FROM "{self.db_name}"."autogen"."{topic_name}"{pstr} {limit}'
 
         # Do query
         ret = await self._do_query(query)
@@ -416,14 +426,20 @@ class EfdClient:
         vals = {'name': [], 'description': [], 'units': [], 'aunits': []}
         for f in fields:
             vals['name'].append(f['name'])
-            vals['description'].append(f['description'])
-            vals['units'].append(f['units'])
-            try:
-                if vals['units'][-1] == 'unitless':  # Special case not having units
-                    vals['aunits'].append(u.dimensionless_unscaled)
-                else:
-                    vals['aunits'].append(u.Unit(vals['units'][-1]))
-            except (ValueError, TypeError) as e:
-                logging.warning(f'Could not construct unist: {e.args[0]}')
+            if 'description' in f:
+                vals['description'].append(f['description'])
+            else:
+                vals['description'].append(None)
+            if 'units' in f:
+                vals['units'].append(f['units'])
+                try:
+                    if vals['units'][-1] == 'unitless':  # Special case not having units
+                        vals['aunits'].append(u.dimensionless_unscaled)
+                    else:
+                        vals['aunits'].append(u.Unit(vals['units'][-1]))
+                except (ValueError, TypeError) as e:
+                    logging.warning(f'Could not construct units: {e.args[0]}')
+            else:
+                vals['units'].append(None)
                 vals['aunits'].append(None)
         return pd.DataFrame(vals)
